@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 
-from .BandPasser import BandPasser
+from ._bandpassfilter import bandpassfilter
 from .fft_powers import calc_fft_powers
 from .wavelet import wavelet
