@@ -3,5 +3,5 @@
 from . import plt
 from .LearningCurveLogger import LearningCurveLogger
 from .merge_labels import merge_labels
-from .Reporter import Reporter
+from .ClassificationReporter import ClassificationReporter
 from .under_sample import under_sample
